@@ -130,8 +130,7 @@ def update_con_with_explicit(cfg, connection):
     return cfg
 
 
-async def create_from_config(path: Path, _connection: Connection = None):
-    # open the config file and read it
+async def resolve_path(path, _connection):
     try:
         if not isinstance(path, Path):
             raise Exception('Must pass pathlib.Path as path')
@@ -144,6 +143,11 @@ async def create_from_config(path: Path, _connection: Connection = None):
 
     if _connection:
         cfg = update_con_with_explicit(cfg, _connection)
+    return cfg
+
+async def create_from_config(path: Path, _connection: Connection = None):
+    # open the config file and read it
+    cfg = await resolve_path(path, _connection)
 
     # connect to the RabbitMQ server
     connection = await connect(cfg)
